# Example Package

This is a Mandrill/Transactional Email MailChimp helper function package. 

To be updated later...
You can use
[Github-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.